@@ -2,6 +2,7 @@ package TestApp::Form::Resource::Artist;
 use HTML::FormHandler::Moose;
 extends 'HTML::FormHandler::Model::DBIC';
 
+has '+enctype'    => ( default => 'multipart/form-data' );
 has '+item_class' => ( default => 'Resource::Artist' );
 
 has_field 'name' => (
@@ -25,6 +26,9 @@ has_field 'password_repeat' => (
     noupdate => 1,
 );
 
+# does not exist in DB, only here to test MergeUploadParams trait
+has_field 'picture' => ( type => 'Upload', );
+
 has_field 'submit' => ( type => 'Submit', value => 'Submit' );
 
 no HTML::FormHandler::Moose;
